# magicgui.widgets._protocols

```{eval-rst}
.. automodule:: magicgui.widgets._protocols

.. autosummary::
   :nosignatures:
   :template: autosummary/protocol-class.rst
   :toctree: ../_autosummary

   WidgetProtocol
   ValueWidgetProtocol
   RangedWidgetProtocol
   SupportsChoices
   CategoricalWidgetProtocol
   SupportsText
   ButtonWidgetProtocol
   SupportsOrientation
   SliderWidgetProtocol
   ContainerProtocol
   BaseApplicationBackend
```
